================
Python Benforder
================


.. image:: https://img.shields.io/pypi/v/python_benforder.svg
        :target: https://pypi.python.org/pypi/python_benforder

.. image:: https://img.shields.io/travis/wakaru44/python_benforder.svg
        :target: https://travis-ci.com/wakaru44/python_benforder

.. image:: https://readthedocs.org/projects/python-benforder/badge/?version=latest
        :target: https://python-benforder.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/wakaru44/python_benforder/shield.svg
     :target: https://pyup.io/repos/github/wakaru44/python_benforder/
     :alt: Updates



A small python CLI tool to check the bendfordness of a bunch of numbers


* Free software: GNU General Public License v3
* Documentation: https://python-benforder.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
